@@ -1,5 +1,6 @@
 ################################################################################
 import functools
+
 def register():
     def wrapped(fn):
         @functools.wraps(fn)
@@ -11,15 +12,16 @@ def register():
     return wrapped
 
 def assignOrder(order):
-  @decorator
   def do_assignment(to_func):
     to_func.order = order
     return to_func
   return do_assignment
 
+@assignOrder(7)
 @register()
 def OutputMethodMetadata(method):
     '''Outputs the stored metadata for the given method object'''
     print(method.methodName)
     print(method.methodDescription)
+
 ################################################################################
\ No newline at end of file
